Go

Struct Go 

#[non_exhaustive]
pub struct Go { pub header: Cow<'static, str>, pub layout: Layout, /* private fields */ }
Go language exporter.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
header: Cow<'static, str>

Content written before the generated Go package declaration.

layout: Layout

The output file layout.

Implementations

Source

impl Go

pub fn new() -> Self

Creates a Go exporter using the default configuration.

pub fn package_name(self, name: impl Into<String>) -> Self

Sets the generated Go package name.

pub fn header(self, header: impl Into<Cow<'static, str>>) -> Self

Sets content written before the generated Go package declaration.

pub fn export( &self, types: &Types, format: impl Format, ) -> Result<String, Error>

Exports the provided types into a Go source file string.

pub fn export_to( &self, path: impl AsRef<Path>, types: &Types, format: impl Format, ) -> Result<(), Error>

Exports the provided types to a Go source file at the given path.